==> jc-1.4.0.tar.gz: javax/swing/undo/CannotRedoException.h <==
// public class javax.swing.undo.CannotRedoException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class b787c9bf9b0bdc61 javax_swing_undo_CannotRedoException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_javax_swing_undo_CannotRedoException_H_
#define _JC_javax_swing_undo_CannotRedoException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_undo_CannotRedoException$sub_refs	_jc_javax_swing_undo_CannotRedoException$sub_refs;
typedef struct _jc_javax_swing_undo_CannotRedoException$sub_nonrefs	_jc_javax_swing_undo_CannotRedoException$sub_nonrefs;
typedef struct _jc_javax_swing_undo_CannotRedoException$refs	_jc_javax_swing_undo_CannotRedoException$refs;
typedef struct _jc_javax_swing_undo_CannotRedoException$nonrefs	_jc_javax_swing_undo_CannotRedoException$nonrefs;
typedef struct _jc_javax_swing_undo_CannotRedoException$object	_jc_javax_swing_undo_CannotRedoException$object;

typedef const struct _jc_javax_swing_undo_CannotRedoException$vmethods	_jc_javax_swing_undo_CannotRedoException$vmethods;
typedef const struct _jc_javax_swing_undo_CannotRedoException$vtable	_jc_javax_swing_undo_CannotRedoException$vtable;
typedef const struct _jc_javax_swing_undo_CannotRedoException$vtype	_jc_javax_swing_undo_CannotRedoException$vtype;

// Constructors
extern void _jc_javax_swing_undo_CannotRedoException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_undo_CannotRedoException$object *);

// Virtual methods structure
struct _jc_javax_swing_undo_CannotRedoException$vmethods {
};

// Vtable
struct _jc_javax_swing_undo_CannotRedoException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_javax_swing_undo_CannotRedoException$vmethods	javax_swing_undo_CannotRedoException;
};

// Vtype
struct _jc_javax_swing_undo_CannotRedoException$vtype {
	_jc_type			type;
	_jc_javax_swing_undo_CannotRedoException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_undo_CannotRedoException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_undo_CannotRedoException$refs {
    _jc_javax_swing_undo_CannotRedoException$sub_refs	javax_swing_undo_CannotRedoException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_undo_CannotRedoException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_undo_CannotRedoException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_javax_swing_undo_CannotRedoException$sub_nonrefs	javax_swing_undo_CannotRedoException;
};

// Object instance structure
struct _jc_javax_swing_undo_CannotRedoException$object {
	_jc_javax_swing_undo_CannotRedoException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_undo_CannotRedoException$vtype	*vtype;
	_jc_javax_swing_undo_CannotRedoException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_undo_CannotRedoException$vtype _jc_javax_swing_undo_CannotRedoException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_undo_CannotRedoException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_undo_CannotRedoException$class_object;

#endif	/* _JC_javax_swing_undo_CannotRedoException_H_ */

==> jc-1.4.6.tar.gz: javax/swing/undo/CannotRedoException.h <==
// public class javax.swing.undo.CannotRedoException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class b787c9bf9b0bdc61 javax_swing_undo_CannotRedoException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_javax_swing_undo_CannotRedoException_H_
#define _JC_javax_swing_undo_CannotRedoException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_undo_CannotRedoException$sub_refs	_jc_javax_swing_undo_CannotRedoException$sub_refs;
typedef struct _jc_javax_swing_undo_CannotRedoException$sub_nonrefs	_jc_javax_swing_undo_CannotRedoException$sub_nonrefs;
typedef struct _jc_javax_swing_undo_CannotRedoException$refs	_jc_javax_swing_undo_CannotRedoException$refs;
typedef struct _jc_javax_swing_undo_CannotRedoException$nonrefs	_jc_javax_swing_undo_CannotRedoException$nonrefs;
typedef struct _jc_javax_swing_undo_CannotRedoException$object	_jc_javax_swing_undo_CannotRedoException$object;

typedef const struct _jc_javax_swing_undo_CannotRedoException$vmethods	_jc_javax_swing_undo_CannotRedoException$vmethods;
typedef const struct _jc_javax_swing_undo_CannotRedoException$vtable	_jc_javax_swing_undo_CannotRedoException$vtable;
typedef const struct _jc_javax_swing_undo_CannotRedoException$vtype	_jc_javax_swing_undo_CannotRedoException$vtype;

// Constructors
extern void _jc_javax_swing_undo_CannotRedoException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_undo_CannotRedoException$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_undo_CannotRedoException$vmethods {
};

// Vtable
struct _jc_javax_swing_undo_CannotRedoException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_javax_swing_undo_CannotRedoException$vmethods	javax_swing_undo_CannotRedoException;
};

// Vtype
struct _jc_javax_swing_undo_CannotRedoException$vtype {
	_jc_type			type;
	_jc_javax_swing_undo_CannotRedoException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_undo_CannotRedoException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_undo_CannotRedoException$refs {
    _jc_javax_swing_undo_CannotRedoException$sub_refs	javax_swing_undo_CannotRedoException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_undo_CannotRedoException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_undo_CannotRedoException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_javax_swing_undo_CannotRedoException$sub_nonrefs	javax_swing_undo_CannotRedoException;
};

// Object instance structure
struct _jc_javax_swing_undo_CannotRedoException$object {
	_jc_javax_swing_undo_CannotRedoException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_undo_CannotRedoException$vtype	*vtype;
	_jc_javax_swing_undo_CannotRedoException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_undo_CannotRedoException$vtype _jc_javax_swing_undo_CannotRedoException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_undo_CannotRedoException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_undo_CannotRedoException$class_object;

#endif	/* _JC_javax_swing_undo_CannotRedoException_H_ */
